#!/usr/bin/env python
# -*- coding: utf-8 -*-

# GIMP plugin to de-haze an image invented by Sallyanne (using G'MIC filters)

# (c) Dinasset 2023
#
#   History:
#
#   v.1.1.0: 2023-11: Initial version
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import sys, os
from gimpfu import *

############################################################################
# Main
#---------------------------------------------------------------------------

def Sallyanne_Dehaze (inImage, inLayer,
                      LCEamt, ELHamt, MDamt, NBamt):
      
    # here the logic of the filter
    pdb.gimp_image_undo_group_start (inImage)
    
    BaseLayer = inLayer.copy()
    inImage.add_layer (BaseLayer, 0)
    BaseLayer.name = "Base (copy of input original layer)"
    
    # 1. Local Contrast Enhancement
    # fx_LCE 80,0.5,1,1,0,0
    parms='80,0.5,1,1,0,0'
    pdb.plug_in_gmic_qt(inImage,BaseLayer, 1,2,
        "-v - -fx_LCE "+str(parms)+" ")
    LCE = inImage.layers[0]
    LCE.name = "1.After applying LCE "+parms
    LCE.opacity = LCEamt
    
    # 2. Equalize Local Histogram
    # fx_equalize_local_histograms 75,2,4,100,8,1,16,0,50,50
    parms='75,2,4,100,8,1,16,0,50,50'
    pdb.plug_in_gmic_qt(inImage,LCE, 1,2,
        "-v - -fx_equalize_local_histograms "+str(parms)+" ")
    ELH = inImage.layers[0]
    ELH.name = "2.After applying ELH "+parms
    ELH.opacity = ELHamt
            
    # 3. Migty Details
    # fx_mighty_details 25,1,25,1,11,0,50,50
    parms='25,1,25,1,11,0,50,50'
    pdb.plug_in_gmic_qt(inImage,ELH, 1,2,
        "-v - -fx_mighty_details "+str(parms)+" ")
    MD = inImage.layers[0]
    MD.name = "3.After applying MD "+parms
    MD.opacity = MDamt
    
    # 4. Normalize Brightness
    # gcd_normalize_brightness 0,10,0,3,0,0
    parms='0,10,0,3,0,0'
    pdb.plug_in_gmic_qt(inImage,MD, 1,2,
        "-v - -gcd_normalize_brightness "+str(parms)+" ")
    NB = inImage.layers[0]
    NB.name = "4.After applying NB "+parms
    NB.opacity = MDamt
      
    # here the end of the filter
    pdb.gimp_image_undo_group_end (inImage)
    
    pdb.gimp_displays_flush ()
    return
             
### Registration
whoiam="\n"+os.path.abspath(sys.argv[0])
author="dinasset from a tutorial by Sallyanne on GF"
menu="<Image>/Sallyanne/Simple/"
copyrightYear="2023"
desc="Sallyanne Dehaze"

register(
    "Sallyanne_Dehaze",
    desc+whoiam,desc,
    author,author,
    copyrightYear,
    "Sallyanne Tutorial for dehazing, version 1.1.0 ",
    "*",
    [
        (PF_IMAGE, "image", "Input image", None),
        (PF_DRAWABLE, "drawable", "Input drawable", None),
        (PF_ADJUSTMENT, "lceamt", "LCE amount",
                                    100, (0, 100, 1)),
        (PF_ADJUSTMENT, "equamt", "Equalize amount",
                                    100, (0, 100, 1)),
        (PF_ADJUSTMENT, "chromaamt", "Mighty details amount",
                                    35, (0, 100, 1)),
        (PF_ADJUSTMENT, "normamt", "Norm. brightness amount",
                                    70, (0, 100, 1)),
    ],
    [],
    Sallyanne_Dehaze,
    menu=menu
)

main()
